@@ -37,10 +37,11 @@ use {
         stake,
         system_instruction::{self, SystemError},
         system_program,
-        transaction::Transaction,
+        transaction::{Transaction, VersionedTransaction},
     },
     solana_transaction_status::{
-        Encodable, EncodedTransaction, TransactionBinaryEncoding, UiTransactionEncoding,
+        EncodableWithMeta, EncodedConfirmedTransactionWithStatusMeta, EncodedTransaction,
+        TransactionBinaryEncoding, UiTransactionEncoding,
     },
     std::{fmt::Write as FmtWrite, fs::File, io::Write, sync::Arc},
 };
@@ -561,23 +562,25 @@ pub fn process_confirm(
                         RpcTransactionConfig {
                             encoding: Some(UiTransactionEncoding::Base64),
                             commitment: Some(CommitmentConfig::confirmed()),
-                            max_supported_transaction_version: None,
+                            max_supported_transaction_version: Some(0),
                         },
                     ) {
                         Ok(confirmed_transaction) => {
-                            let decoded_transaction = confirmed_transaction
-                                .transaction
-                                .transaction
-                                .decode()
-                                .expect("Successful decode");
-                            let json_transaction =
-                                decoded_transaction.encode(UiTransactionEncoding::Json);
+                            let EncodedConfirmedTransactionWithStatusMeta {
+                                block_time,
+                                slot,
+                                transaction: transaction_with_meta,
+                            } = confirmed_transaction;
+
+                            let decoded_transaction =
+                                transaction_with_meta.transaction.decode().unwrap();
+                            let json_transaction = decoded_transaction.json_encode();
 
                             transaction = Some(CliTransaction {
                                 transaction: json_transaction,
-                                meta: confirmed_transaction.transaction.meta,
-                                block_time: confirmed_transaction.block_time,
-                                slot: Some(confirmed_transaction.slot),
+                                meta: transaction_with_meta.meta,
+                                block_time,
+                                slot: Some(slot),
                                 decoded_transaction,
                                 prefix: "  ".to_string(),
                                 sigverify_status: vec![],
@@ -609,11 +612,14 @@ pub fn process_confirm(
 }
 
 #[allow(clippy::unnecessary_wraps)]
-pub fn process_decode_transaction(config: &CliConfig, transaction: &Transaction) -> ProcessResult {
+pub fn process_decode_transaction(
+    config: &CliConfig,
+    transaction: &VersionedTransaction,
+) -> ProcessResult {
     let sigverify_status = CliSignatureVerificationStatus::verify_transaction(transaction);
     let decode_transaction = CliTransaction {
         decoded_transaction: transaction.clone(),
-        transaction: transaction.encode(UiTransactionEncoding::Json),
+        transaction: transaction.json_encode(),
         meta: None,
         block_time: None,
         slot: None,
